# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[str],
                 group_id: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 group_type: Optional[pulumi.Input[str]] = None,
                 read_enable: Optional[pulumi.Input[bool]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[str] instance_id: ID of the ONS Instance that owns the groups.
        :param pulumi.Input[str] group_id: Replaced by `group_name` after version 1.98.0.
        :param pulumi.Input[str] group_name: Name of the group. Two groups on a single instance cannot have the same name. A `group_name` starts with "GID_" or "GID-", and contains letters, numbers, hyphens (-), and underscores (_).
        :param pulumi.Input[str] group_type: Specify the protocol applicable to the created Group ID. Valid values: `tcp`, `http`. Default to `tcp`.
        :param pulumi.Input[bool] read_enable: This attribute is used to set the message reading enabled or disabled. It can only be set after the group is used by the client.
        :param pulumi.Input[str] remark: This attribute is a concise description of group. The length cannot exceed 256.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
               - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
               - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        pulumi.set(__self__, "instance_id", instance_id)
        if group_id is not None:
            warnings.warn("""Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""group_id is deprecated: Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""")
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if group_type is not None:
            pulumi.set(__self__, "group_type", group_type)
        if read_enable is not None:
            pulumi.set(__self__, "read_enable", read_enable)
        if remark is not None:
            pulumi.set(__self__, "remark", remark)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        ID of the ONS Instance that owns the groups.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        Replaced by `group_name` after version 1.98.0.
        """
        warnings.warn("""Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""", DeprecationWarning)
        pulumi.log.warn("""group_id is deprecated: Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""")

        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the group. Two groups on a single instance cannot have the same name. A `group_name` starts with "GID_" or "GID-", and contains letters, numbers, hyphens (-), and underscores (_).
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="groupType")
    def group_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the protocol applicable to the created Group ID. Valid values: `tcp`, `http`. Default to `tcp`.
        """
        return pulumi.get(self, "group_type")

    @group_type.setter
    def group_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_type", value)

    @property
    @pulumi.getter(name="readEnable")
    def read_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        This attribute is used to set the message reading enabled or disabled. It can only be set after the group is used by the client.
        """
        return pulumi.get(self, "read_enable")

    @read_enable.setter
    def read_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "read_enable", value)

    @property
    @pulumi.getter
    def remark(self) -> Optional[pulumi.Input[str]]:
        """
        This attribute is a concise description of group. The length cannot exceed 256.
        """
        return pulumi.get(self, "remark")

    @remark.setter
    def remark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remark", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
        - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 group_id: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 group_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 read_enable: Optional[pulumi.Input[bool]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[str] group_id: Replaced by `group_name` after version 1.98.0.
        :param pulumi.Input[str] group_name: Name of the group. Two groups on a single instance cannot have the same name. A `group_name` starts with "GID_" or "GID-", and contains letters, numbers, hyphens (-), and underscores (_).
        :param pulumi.Input[str] group_type: Specify the protocol applicable to the created Group ID. Valid values: `tcp`, `http`. Default to `tcp`.
        :param pulumi.Input[str] instance_id: ID of the ONS Instance that owns the groups.
        :param pulumi.Input[bool] read_enable: This attribute is used to set the message reading enabled or disabled. It can only be set after the group is used by the client.
        :param pulumi.Input[str] remark: This attribute is a concise description of group. The length cannot exceed 256.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
               - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
               - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        if group_id is not None:
            warnings.warn("""Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""group_id is deprecated: Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""")
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if group_type is not None:
            pulumi.set(__self__, "group_type", group_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if read_enable is not None:
            pulumi.set(__self__, "read_enable", read_enable)
        if remark is not None:
            pulumi.set(__self__, "remark", remark)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        Replaced by `group_name` after version 1.98.0.
        """
        warnings.warn("""Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""", DeprecationWarning)
        pulumi.log.warn("""group_id is deprecated: Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""")

        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the group. Two groups on a single instance cannot have the same name. A `group_name` starts with "GID_" or "GID-", and contains letters, numbers, hyphens (-), and underscores (_).
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="groupType")
    def group_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the protocol applicable to the created Group ID. Valid values: `tcp`, `http`. Default to `tcp`.
        """
        return pulumi.get(self, "group_type")

    @group_type.setter
    def group_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the ONS Instance that owns the groups.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="readEnable")
    def read_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        This attribute is used to set the message reading enabled or disabled. It can only be set after the group is used by the client.
        """
        return pulumi.get(self, "read_enable")

    @read_enable.setter
    def read_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "read_enable", value)

    @property
    @pulumi.getter
    def remark(self) -> Optional[pulumi.Input[str]]:
        """
        This attribute is a concise description of group. The length cannot exceed 256.
        """
        return pulumi.get(self, "remark")

    @remark.setter
    def remark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remark", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
        - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 group_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 read_enable: Optional[pulumi.Input[bool]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        """
        Provides an ONS group resource.

        For more information about how to use it, see [RocketMQ Group Management API](https://www.alibabacloud.com/help/doc-detail/29616.html).

        > **NOTE:** Available in 1.53.0+

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "onsInstanceName"
        group_name = config.get("groupName")
        if group_name is None:
            group_name = "GID-onsGroupDatasourceName"
        default_instance = alicloud.rocketmq.Instance("defaultInstance", remark="default_ons_instance_remark")
        default_group = alicloud.rocketmq.Group("defaultGroup",
            group_name=group_name,
            instance_id=default_instance.id,
            remark="dafault_ons_group_remark")
        ```

        ## Import

        ONS GROUP can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:rocketmq/group:Group group MQ_INST_1234567890_Baso1234567:GID-onsGroupDemo
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: Replaced by `group_name` after version 1.98.0.
        :param pulumi.Input[str] group_name: Name of the group. Two groups on a single instance cannot have the same name. A `group_name` starts with "GID_" or "GID-", and contains letters, numbers, hyphens (-), and underscores (_).
        :param pulumi.Input[str] group_type: Specify the protocol applicable to the created Group ID. Valid values: `tcp`, `http`. Default to `tcp`.
        :param pulumi.Input[str] instance_id: ID of the ONS Instance that owns the groups.
        :param pulumi.Input[bool] read_enable: This attribute is used to set the message reading enabled or disabled. It can only be set after the group is used by the client.
        :param pulumi.Input[str] remark: This attribute is a concise description of group. The length cannot exceed 256.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
               - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
               - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an ONS group resource.

        For more information about how to use it, see [RocketMQ Group Management API](https://www.alibabacloud.com/help/doc-detail/29616.html).

        > **NOTE:** Available in 1.53.0+

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "onsInstanceName"
        group_name = config.get("groupName")
        if group_name is None:
            group_name = "GID-onsGroupDatasourceName"
        default_instance = alicloud.rocketmq.Instance("defaultInstance", remark="default_ons_instance_remark")
        default_group = alicloud.rocketmq.Group("defaultGroup",
            group_name=group_name,
            instance_id=default_instance.id,
            remark="dafault_ons_group_remark")
        ```

        ## Import

        ONS GROUP can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:rocketmq/group:Group group MQ_INST_1234567890_Baso1234567:GID-onsGroupDemo
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 group_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 read_enable: Optional[pulumi.Input[bool]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            if group_id is not None and not opts.urn:
                warnings.warn("""Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""", DeprecationWarning)
                pulumi.log.warn("""group_id is deprecated: Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["group_name"] = group_name
            __props__.__dict__["group_type"] = group_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["read_enable"] = read_enable
            __props__.__dict__["remark"] = remark
            __props__.__dict__["tags"] = tags
        super(Group, __self__).__init__(
            'alicloud:rocketmq/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            group_name: Optional[pulumi.Input[str]] = None,
            group_type: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            read_enable: Optional[pulumi.Input[bool]] = None,
            remark: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, Any]]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: Replaced by `group_name` after version 1.98.0.
        :param pulumi.Input[str] group_name: Name of the group. Two groups on a single instance cannot have the same name. A `group_name` starts with "GID_" or "GID-", and contains letters, numbers, hyphens (-), and underscores (_).
        :param pulumi.Input[str] group_type: Specify the protocol applicable to the created Group ID. Valid values: `tcp`, `http`. Default to `tcp`.
        :param pulumi.Input[str] instance_id: ID of the ONS Instance that owns the groups.
        :param pulumi.Input[bool] read_enable: This attribute is used to set the message reading enabled or disabled. It can only be set after the group is used by the client.
        :param pulumi.Input[str] remark: This attribute is a concise description of group. The length cannot exceed 256.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
               - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
               - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["group_type"] = group_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["read_enable"] = read_enable
        __props__.__dict__["remark"] = remark
        __props__.__dict__["tags"] = tags
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        Replaced by `group_name` after version 1.98.0.
        """
        warnings.warn("""Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""", DeprecationWarning)
        pulumi.log.warn("""group_id is deprecated: Field 'group_id' has been deprecated from version 1.98.0. Use 'group_name' instead.""")

        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Output[str]:
        """
        Name of the group. Two groups on a single instance cannot have the same name. A `group_name` starts with "GID_" or "GID-", and contains letters, numbers, hyphens (-), and underscores (_).
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="groupType")
    def group_type(self) -> pulumi.Output[Optional[str]]:
        """
        Specify the protocol applicable to the created Group ID. Valid values: `tcp`, `http`. Default to `tcp`.
        """
        return pulumi.get(self, "group_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        ID of the ONS Instance that owns the groups.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="readEnable")
    def read_enable(self) -> pulumi.Output[Optional[bool]]:
        """
        This attribute is used to set the message reading enabled or disabled. It can only be set after the group is used by the client.
        """
        return pulumi.get(self, "read_enable")

    @property
    @pulumi.getter
    def remark(self) -> pulumi.Output[Optional[str]]:
        """
        This attribute is a concise description of group. The length cannot exceed 256.
        """
        return pulumi.get(self, "remark")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        - Key: It can be up to 64 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It cannot be a null string.
        - Value: It can be up to 128 characters in length. It cannot begin with "aliyun", "acs:", "http://", or "https://". It can be a null string.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayArgs', 'Gateway']

@pulumi.input_type
class GatewayArgs:
    def __init__(__self__, *,
                 replica: pulumi.Input[int],
                 spec: pulumi.Input[str],
                 vpc_id: pulumi.Input[str],
                 vswitch_id: pulumi.Input[str],
                 backup_vswitch_id: Optional[pulumi.Input[str]] = None,
                 delete_slb: Optional[pulumi.Input[bool]] = None,
                 enterprise_security_group: Optional[pulumi.Input[bool]] = None,
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 internet_slb_spec: Optional[pulumi.Input[str]] = None,
                 slb_spec: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Gateway resource.
        :param pulumi.Input[int] replica: Number of Gateway Nodes.
        :param pulumi.Input[str] spec: Gateway Node Specifications. Valid values: `MSE_GTW_2_4_200_c`, `MSE_GTW_4_8_200_c`, `MSE_GTW_8_16_200_c`, `MSE_GTW_16_32_200_c`.
        :param pulumi.Input[str] vpc_id: The ID of the vpc.
        :param pulumi.Input[str] vswitch_id: The ID of the vswitch.
        :param pulumi.Input[str] backup_vswitch_id: The backup vswitch id.
        :param pulumi.Input[bool] delete_slb: Whether to delete the SLB purchased on behalf of the gateway at the same time.
        :param pulumi.Input[bool] enterprise_security_group: Whether the enterprise security group type.
        :param pulumi.Input[str] gateway_name: The name of the Gateway .
        :param pulumi.Input[str] internet_slb_spec: Public network SLB specifications.
        :param pulumi.Input[str] slb_spec: Private network SLB specifications.
        """
        pulumi.set(__self__, "replica", replica)
        pulumi.set(__self__, "spec", spec)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if backup_vswitch_id is not None:
            pulumi.set(__self__, "backup_vswitch_id", backup_vswitch_id)
        if delete_slb is not None:
            pulumi.set(__self__, "delete_slb", delete_slb)
        if enterprise_security_group is not None:
            pulumi.set(__self__, "enterprise_security_group", enterprise_security_group)
        if gateway_name is not None:
            pulumi.set(__self__, "gateway_name", gateway_name)
        if internet_slb_spec is not None:
            pulumi.set(__self__, "internet_slb_spec", internet_slb_spec)
        if slb_spec is not None:
            pulumi.set(__self__, "slb_spec", slb_spec)

    @property
    @pulumi.getter
    def replica(self) -> pulumi.Input[int]:
        """
        Number of Gateway Nodes.
        """
        return pulumi.get(self, "replica")

    @replica.setter
    def replica(self, value: pulumi.Input[int]):
        pulumi.set(self, "replica", value)

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Input[str]:
        """
        Gateway Node Specifications. Valid values: `MSE_GTW_2_4_200_c`, `MSE_GTW_4_8_200_c`, `MSE_GTW_8_16_200_c`, `MSE_GTW_16_32_200_c`.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: pulumi.Input[str]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the vpc.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The ID of the vswitch.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="backupVswitchId")
    def backup_vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The backup vswitch id.
        """
        return pulumi.get(self, "backup_vswitch_id")

    @backup_vswitch_id.setter
    def backup_vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backup_vswitch_id", value)

    @property
    @pulumi.getter(name="deleteSlb")
    def delete_slb(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to delete the SLB purchased on behalf of the gateway at the same time.
        """
        return pulumi.get(self, "delete_slb")

    @delete_slb.setter
    def delete_slb(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_slb", value)

    @property
    @pulumi.getter(name="enterpriseSecurityGroup")
    def enterprise_security_group(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the enterprise security group type.
        """
        return pulumi.get(self, "enterprise_security_group")

    @enterprise_security_group.setter
    def enterprise_security_group(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enterprise_security_group", value)

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Gateway .
        """
        return pulumi.get(self, "gateway_name")

    @gateway_name.setter
    def gateway_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_name", value)

    @property
    @pulumi.getter(name="internetSlbSpec")
    def internet_slb_spec(self) -> Optional[pulumi.Input[str]]:
        """
        Public network SLB specifications.
        """
        return pulumi.get(self, "internet_slb_spec")

    @internet_slb_spec.setter
    def internet_slb_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_spec", value)

    @property
    @pulumi.getter(name="slbSpec")
    def slb_spec(self) -> Optional[pulumi.Input[str]]:
        """
        Private network SLB specifications.
        """
        return pulumi.get(self, "slb_spec")

    @slb_spec.setter
    def slb_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slb_spec", value)


@pulumi.input_type
class _GatewayState:
    def __init__(__self__, *,
                 backup_vswitch_id: Optional[pulumi.Input[str]] = None,
                 delete_slb: Optional[pulumi.Input[bool]] = None,
                 enterprise_security_group: Optional[pulumi.Input[bool]] = None,
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 internet_slb_spec: Optional[pulumi.Input[str]] = None,
                 replica: Optional[pulumi.Input[int]] = None,
                 slb_lists: Optional[pulumi.Input[Sequence[pulumi.Input['GatewaySlbListArgs']]]] = None,
                 slb_spec: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Gateway resources.
        :param pulumi.Input[str] backup_vswitch_id: The backup vswitch id.
        :param pulumi.Input[bool] delete_slb: Whether to delete the SLB purchased on behalf of the gateway at the same time.
        :param pulumi.Input[bool] enterprise_security_group: Whether the enterprise security group type.
        :param pulumi.Input[str] gateway_name: The name of the Gateway .
        :param pulumi.Input[str] internet_slb_spec: Public network SLB specifications.
        :param pulumi.Input[int] replica: Number of Gateway Nodes.
        :param pulumi.Input[Sequence[pulumi.Input['GatewaySlbListArgs']]] slb_lists: A list of gateway Slb.
        :param pulumi.Input[str] slb_spec: Private network SLB specifications.
        :param pulumi.Input[str] spec: Gateway Node Specifications. Valid values: `MSE_GTW_2_4_200_c`, `MSE_GTW_4_8_200_c`, `MSE_GTW_8_16_200_c`, `MSE_GTW_16_32_200_c`.
        :param pulumi.Input[str] status: The status of the gateway.
        :param pulumi.Input[str] vpc_id: The ID of the vpc.
        :param pulumi.Input[str] vswitch_id: The ID of the vswitch.
        """
        if backup_vswitch_id is not None:
            pulumi.set(__self__, "backup_vswitch_id", backup_vswitch_id)
        if delete_slb is not None:
            pulumi.set(__self__, "delete_slb", delete_slb)
        if enterprise_security_group is not None:
            pulumi.set(__self__, "enterprise_security_group", enterprise_security_group)
        if gateway_name is not None:
            pulumi.set(__self__, "gateway_name", gateway_name)
        if internet_slb_spec is not None:
            pulumi.set(__self__, "internet_slb_spec", internet_slb_spec)
        if replica is not None:
            pulumi.set(__self__, "replica", replica)
        if slb_lists is not None:
            pulumi.set(__self__, "slb_lists", slb_lists)
        if slb_spec is not None:
            pulumi.set(__self__, "slb_spec", slb_spec)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="backupVswitchId")
    def backup_vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The backup vswitch id.
        """
        return pulumi.get(self, "backup_vswitch_id")

    @backup_vswitch_id.setter
    def backup_vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backup_vswitch_id", value)

    @property
    @pulumi.getter(name="deleteSlb")
    def delete_slb(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to delete the SLB purchased on behalf of the gateway at the same time.
        """
        return pulumi.get(self, "delete_slb")

    @delete_slb.setter
    def delete_slb(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_slb", value)

    @property
    @pulumi.getter(name="enterpriseSecurityGroup")
    def enterprise_security_group(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the enterprise security group type.
        """
        return pulumi.get(self, "enterprise_security_group")

    @enterprise_security_group.setter
    def enterprise_security_group(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enterprise_security_group", value)

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Gateway .
        """
        return pulumi.get(self, "gateway_name")

    @gateway_name.setter
    def gateway_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_name", value)

    @property
    @pulumi.getter(name="internetSlbSpec")
    def internet_slb_spec(self) -> Optional[pulumi.Input[str]]:
        """
        Public network SLB specifications.
        """
        return pulumi.get(self, "internet_slb_spec")

    @internet_slb_spec.setter
    def internet_slb_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_spec", value)

    @property
    @pulumi.getter
    def replica(self) -> Optional[pulumi.Input[int]]:
        """
        Number of Gateway Nodes.
        """
        return pulumi.get(self, "replica")

    @replica.setter
    def replica(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "replica", value)

    @property
    @pulumi.getter(name="slbLists")
    def slb_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewaySlbListArgs']]]]:
        """
        A list of gateway Slb.
        """
        return pulumi.get(self, "slb_lists")

    @slb_lists.setter
    def slb_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewaySlbListArgs']]]]):
        pulumi.set(self, "slb_lists", value)

    @property
    @pulumi.getter(name="slbSpec")
    def slb_spec(self) -> Optional[pulumi.Input[str]]:
        """
        Private network SLB specifications.
        """
        return pulumi.get(self, "slb_spec")

    @slb_spec.setter
    def slb_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slb_spec", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[str]]:
        """
        Gateway Node Specifications. Valid values: `MSE_GTW_2_4_200_c`, `MSE_GTW_4_8_200_c`, `MSE_GTW_8_16_200_c`, `MSE_GTW_16_32_200_c`.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the gateway.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the vpc.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the vswitch.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class Gateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_vswitch_id: Optional[pulumi.Input[str]] = None,
                 delete_slb: Optional[pulumi.Input[bool]] = None,
                 enterprise_security_group: Optional[pulumi.Input[bool]] = None,
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 internet_slb_spec: Optional[pulumi.Input[str]] = None,
                 replica: Optional[pulumi.Input[int]] = None,
                 slb_spec: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Microservice Engine (MSE) Gateway resource.

        For information about Microservice Engine (MSE) Gateway and how to use it, see [What is Gateway](https://help.aliyun.com/document_detail/347638.html).

        > **NOTE:** Available in v1.157.0+.

        ## Import

        Microservice Engine (MSE) Gateway can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:mse/gateway:Gateway example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_vswitch_id: The backup vswitch id.
        :param pulumi.Input[bool] delete_slb: Whether to delete the SLB purchased on behalf of the gateway at the same time.
        :param pulumi.Input[bool] enterprise_security_group: Whether the enterprise security group type.
        :param pulumi.Input[str] gateway_name: The name of the Gateway .
        :param pulumi.Input[str] internet_slb_spec: Public network SLB specifications.
        :param pulumi.Input[int] replica: Number of Gateway Nodes.
        :param pulumi.Input[str] slb_spec: Private network SLB specifications.
        :param pulumi.Input[str] spec: Gateway Node Specifications. Valid values: `MSE_GTW_2_4_200_c`, `MSE_GTW_4_8_200_c`, `MSE_GTW_8_16_200_c`, `MSE_GTW_16_32_200_c`.
        :param pulumi.Input[str] vpc_id: The ID of the vpc.
        :param pulumi.Input[str] vswitch_id: The ID of the vswitch.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Microservice Engine (MSE) Gateway resource.

        For information about Microservice Engine (MSE) Gateway and how to use it, see [What is Gateway](https://help.aliyun.com/document_detail/347638.html).

        > **NOTE:** Available in v1.157.0+.

        ## Import

        Microservice Engine (MSE) Gateway can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:mse/gateway:Gateway example <id>
        ```

        :param str resource_name: The name of the resource.
        :param GatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_vswitch_id: Optional[pulumi.Input[str]] = None,
                 delete_slb: Optional[pulumi.Input[bool]] = None,
                 enterprise_security_group: Optional[pulumi.Input[bool]] = None,
                 gateway_name: Optional[pulumi.Input[str]] = None,
                 internet_slb_spec: Optional[pulumi.Input[str]] = None,
                 replica: Optional[pulumi.Input[int]] = None,
                 slb_spec: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayArgs.__new__(GatewayArgs)

            __props__.__dict__["backup_vswitch_id"] = backup_vswitch_id
            __props__.__dict__["delete_slb"] = delete_slb
            __props__.__dict__["enterprise_security_group"] = enterprise_security_group
            __props__.__dict__["gateway_name"] = gateway_name
            __props__.__dict__["internet_slb_spec"] = internet_slb_spec
            if replica is None and not opts.urn:
                raise TypeError("Missing required property 'replica'")
            __props__.__dict__["replica"] = replica
            __props__.__dict__["slb_spec"] = slb_spec
            if spec is None and not opts.urn:
                raise TypeError("Missing required property 'spec'")
            __props__.__dict__["spec"] = spec
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["slb_lists"] = None
            __props__.__dict__["status"] = None
        super(Gateway, __self__).__init__(
            'alicloud:mse/gateway:Gateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_vswitch_id: Optional[pulumi.Input[str]] = None,
            delete_slb: Optional[pulumi.Input[bool]] = None,
            enterprise_security_group: Optional[pulumi.Input[bool]] = None,
            gateway_name: Optional[pulumi.Input[str]] = None,
            internet_slb_spec: Optional[pulumi.Input[str]] = None,
            replica: Optional[pulumi.Input[int]] = None,
            slb_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GatewaySlbListArgs']]]]] = None,
            slb_spec: Optional[pulumi.Input[str]] = None,
            spec: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'Gateway':
        """
        Get an existing Gateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_vswitch_id: The backup vswitch id.
        :param pulumi.Input[bool] delete_slb: Whether to delete the SLB purchased on behalf of the gateway at the same time.
        :param pulumi.Input[bool] enterprise_security_group: Whether the enterprise security group type.
        :param pulumi.Input[str] gateway_name: The name of the Gateway .
        :param pulumi.Input[str] internet_slb_spec: Public network SLB specifications.
        :param pulumi.Input[int] replica: Number of Gateway Nodes.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GatewaySlbListArgs']]]] slb_lists: A list of gateway Slb.
        :param pulumi.Input[str] slb_spec: Private network SLB specifications.
        :param pulumi.Input[str] spec: Gateway Node Specifications. Valid values: `MSE_GTW_2_4_200_c`, `MSE_GTW_4_8_200_c`, `MSE_GTW_8_16_200_c`, `MSE_GTW_16_32_200_c`.
        :param pulumi.Input[str] status: The status of the gateway.
        :param pulumi.Input[str] vpc_id: The ID of the vpc.
        :param pulumi.Input[str] vswitch_id: The ID of the vswitch.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayState.__new__(_GatewayState)

        __props__.__dict__["backup_vswitch_id"] = backup_vswitch_id
        __props__.__dict__["delete_slb"] = delete_slb
        __props__.__dict__["enterprise_security_group"] = enterprise_security_group
        __props__.__dict__["gateway_name"] = gateway_name
        __props__.__dict__["internet_slb_spec"] = internet_slb_spec
        __props__.__dict__["replica"] = replica
        __props__.__dict__["slb_lists"] = slb_lists
        __props__.__dict__["slb_spec"] = slb_spec
        __props__.__dict__["spec"] = spec
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        return Gateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupVswitchId")
    def backup_vswitch_id(self) -> pulumi.Output[Optional[str]]:
        """
        The backup vswitch id.
        """
        return pulumi.get(self, "backup_vswitch_id")

    @property
    @pulumi.getter(name="deleteSlb")
    def delete_slb(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to delete the SLB purchased on behalf of the gateway at the same time.
        """
        return pulumi.get(self, "delete_slb")

    @property
    @pulumi.getter(name="enterpriseSecurityGroup")
    def enterprise_security_group(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the enterprise security group type.
        """
        return pulumi.get(self, "enterprise_security_group")

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the Gateway .
        """
        return pulumi.get(self, "gateway_name")

    @property
    @pulumi.getter(name="internetSlbSpec")
    def internet_slb_spec(self) -> pulumi.Output[Optional[str]]:
        """
        Public network SLB specifications.
        """
        return pulumi.get(self, "internet_slb_spec")

    @property
    @pulumi.getter
    def replica(self) -> pulumi.Output[int]:
        """
        Number of Gateway Nodes.
        """
        return pulumi.get(self, "replica")

    @property
    @pulumi.getter(name="slbLists")
    def slb_lists(self) -> pulumi.Output[Sequence['outputs.GatewaySlbList']]:
        """
        A list of gateway Slb.
        """
        return pulumi.get(self, "slb_lists")

    @property
    @pulumi.getter(name="slbSpec")
    def slb_spec(self) -> pulumi.Output[Optional[str]]:
        """
        Private network SLB specifications.
        """
        return pulumi.get(self, "slb_spec")

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Output[str]:
        """
        Gateway Node Specifications. Valid values: `MSE_GTW_2_4_200_c`, `MSE_GTW_4_8_200_c`, `MSE_GTW_8_16_200_c`, `MSE_GTW_16_32_200_c`.
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the gateway.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of the vpc.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        """
        The ID of the vswitch.
        """
        return pulumi.get(self, "vswitch_id")

